@@ -19,21 +19,20 @@
 #' pounds(c(100, 0.23, 1.456565, 2e3))
 #' pounds(c(1:10 * 10))
 #' pounds(10^(1:8))
-pounds_format <- function(x, largest_with_penny = 100000) {
-
-  function(x) {
-    x <- plyr::round_any(x, 0.01)
-    if (max(x, na.rm = TRUE) < largest_with_penny &
-          !all(x == floor(x), na.rm = TRUE)) {
-      nsmall <- 2L
-    } else {
-      x <- plyr::round_any(x, 1)
-      nsmall <- 0L
+pounds_format <- function(x, largest_with_penny = 1e+05) {
+    
+    function(x) {
+        x <- plyr::round_any(x, 0.01)
+        if (max(x, na.rm = TRUE) < largest_with_penny & !all(x == floor(x), na.rm = TRUE)) {
+            nsmall <- 2L
+        } else {
+            x <- plyr::round_any(x, 1)
+            nsmall <- 0L
+        }
+        stringr::str_c("\u00a3", format(x, nsmall = nsmall, trim = TRUE, big.mark = ",", scientific = FALSE, digits = 1L))
     }
-    stringr::str_c("\u00A3", format(x, nsmall = nsmall, trim = TRUE, big.mark = ",", scientific = FALSE, digits=1L))
-  }
 }
 
 #' @export
 #' @rdname pounds_format
-pounds <- pounds_format()
+pounds <- pounds_format() 
